function xyN=EndsAlign(xy,varargin)
%% aligns movement ends according to the longest movement
%% required data format: record,frame,x1,y1,x2,y2,...,xn,yn
% 
% INPUT:    xy = data matrix containing movements
%                with columns: traceID,unitID,x1,y1,x2,y2,...,xn,yn
%           varargin = whether to substitute NaN points with next point 0=no.
%
% OUTPUT:   xyN = data matrix containing aligned movements
%                 with columns: unitID,x1,y1,x2,y2,...xn,yn 
%
% RMF, 2019.

%% Check and set arguments.
narginchk(1,2); %check number of input arguments.
nargoutchk(1,1); %check number of output arguments.
if nargin==2
    varargin{1}=logical(varargin{1}*1); %set varargin to 1 if not 0.
else
    varargin{1}=true; %set varargin to true, if not 0.
end

%% Align all recorded movements according to relative duration.
if ~varargin{1}
    xy(isnan(xy))=Inf; %substitute all NaN with Inf.
end
maxis=accumarray(xy(:,1),xy(:,2),[],@max,NaN); %max frames per record.
maxis=maxis(~isnan(maxis)); %max frames per record.
xyN=zeros(round(max(maxis)),(size(xy,2)-2)*length(maxis)); %preallocate for xyN with max duration.
records=unique(xy(:,1));
for n=1:length(records)
    temp=xy(xy(:,1)==records(n),:); %data of record n.
    temp(:,end+1)=ceil(temp(:,2)/max(temp(:,2))*round(max(maxis))); %add aligned video frames.
    temp2=[];
    for m=3:size(xy,2)
        temp2=[temp2,accumarray(temp(:,end),temp(:,m),[],@mean,NaN)]; %add location data.
    end
    temp2(end,isnan(temp2(end,:)))=Inf; %substitute NaN in last line with Inf.
    while all(sum(isnan(temp2))>0)
        temp2(isnan(temp2))=temp2(find(isnan(temp2))+1); %substitute empty with next locs.
    end
    temp2(temp2==Inf)=NaN; %substitute all Inf with NaN.
    xyN(1:round(max(maxis)),(n-1)*(size(xy,2)-2)+1:n*(size(xy,2)-2))=temp2;
end
xyN=[(1:round(max(maxis)))',xyN]; %add aligned video frames.

end